==> certmanager-model-v1-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1/ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodObjectMeta,ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodObjectMeta instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withLabels(instance.getLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withLabels(instance.getLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta build() {
    ACMEChallengeSolverHTTP01IngressPodObjectMeta buildable = new ACMEChallengeSolverHTTP01IngressPodObjectMeta(fluent.getAnnotations(),fluent.getLabels());
    return buildable;
  }
  
}

==> certmanager-model-7.4.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1/ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodObjectMeta,ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder() {
    this(new ACMEChallengeSolverHTTP01IngressPodObjectMeta());
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodObjectMeta());
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<?> fluent;
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta build() {
    ACMEChallengeSolverHTTP01IngressPodObjectMeta buildable = new ACMEChallengeSolverHTTP01IngressPodObjectMeta(fluent.getAnnotations(),fluent.getLabels());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
